# Tutorials

These tutorials walk through how to use Starsim. If you want to explore them interactively, you can run them locally with Jupyter (run `jupyter lab` or `jupyter notebook` in this folder), as long as `jupytext` is installed. You can also run them  through the [Quarto extension](https://marketplace.visualstudio.com/items?itemName=quarto.quarto) for VS Code or via [Positron](https://posit.co/products/ide/positron/)). Finally, you can convert them from Markdown to Jupyter format by running `convert_notebooks.sh`.
